#
# spec file for package quilter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           quilter
Version:        1.6.8
Release:        1.1
Summary:        Writing application
License:        GPL-3.0-only
Group:          Productivity/Office/Word Processor
URL:            https://github.com/lainsce/quilter
Source:         https://github.com/lainsce/quilter/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmarkdown-devel
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Recommends:     %{name}-lang

%description
A fullscreen word processor for Elementary OS.

%lang_package

%prep
%setup -q

# use default font
sed -i '/QuiltMono.ttf/d' $(grep -rl QuiltMono.ttf)

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.lainsce.quilter GTK Utility TimeUtility
%find_lang com.github.lainsce.quilter %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/com.github.lainsce.quilter
%{_datadir}/com.github.lainsce.quilter/
%{_datadir}/applications/com.github.lainsce.quilter.desktop
%{_datadir}/glib-2.0/schemas/com.github.lainsce.quilter.gschema.xml
%{_datadir}/gtksourceview-3.0/styles/*.xml
%{_datadir}/icons/hicolor/*/apps/com.github.lainsce.quilter.??g
%{_datadir}/metainfo/com.github.lainsce.quilter.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Oct 22 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.8:
  * Finally the Sidebar!
  * Some radiobuttons for choices of font & tracking type.
* Mon Sep 24 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.6:
  * All text passes a contrast check to be readable now.
* Mon Sep 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.5:
  * Track words, chars or lines.
  * meson: cleanup post_install script
  * meson: drop lib prefix for libmarkdown
  * CLI option to start with view page shown
  * Fix: view page did not show on start
* Sat Aug 18 2018 avvissu@yandex.by
- Update to 1.6.3:
  * GResource the custom icons
  * Update com.github.lainsce.quilter.appdata.xml
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 1.6.1:
  * Some file changes
  * Add search jump buttons
  * Finalize searchbar things
  * Highlight searches, but it gets gaudy in dark mode
  * Update README.md
  * remove stray spaces
  * Restore this file
  * fix this dependency wrecking havoc
  * Update email
  * Add ja to LINGUAS
  * Clean it all up, and show unicode finally
  * Typerwriter scrolling support for empty document
  * Use default value from SourceView widget when resetting margin
  * Add bottom margin when Typewriter Scrolling Enabled
- Switch to metainfo from appdata
- Remove obsolete macros
* Tue May  8 2018 avvissu@yandex.by
- Update to 1.5.6:
  * fix even more stuff on LaTeX support.
  * LaTeX math support!
  * Update LINGUAS
* Sat Apr 28 2018 avvissu@yandex.by
- Update to 1.5.5:
  * fix maximize/fullscreen problem
  * Update README.md
* Sun Mar 25 2018 badshah400@gmail.com
- Update to version 1.5.4:
  * Fix appdata.
- Changes from version 1.5.3:
  * Preview Mode won't load rogue Javascript code.
  * Preview Mode will also not autojump to the start of the scroll
    at any time.
  * Header becomes Heading in the Cheatsheet.
  * Fixed the Unsaved changes dialog still killing files when
    pressing the New File button.
  * Updated translations.
- Only run post[un] scripts for openSUSE < 1500; for later
  versions rpm file triggers take care of these already.
* Fri Feb 23 2018 avvissu@yandex.by
- Update to 1.5.2:
  * The Headerbar respects the global theme
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.5.1:
  * - Fix for AppCenter
  * 1.5.0 - Fix the New File button to not nuke old files
* Tue Jan 30 2018 avvissu@yandex.by
- Update to 1.4.8:
  * Autosave works properly / Fixed Focus Mode highlight
    preferences
  * change screenshot in readme
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 1.4.6:
  * 1.4.5 - update metadata files
  * 1.4.5- even more flatpak friendly
  * 1.4.5 - Focus only current sentence (PR #116 from wyhasany)
  * Add focus type configuration option in Preferences window
  * Focus only current sentence
* Sat Jan  6 2018 avvissu@yandex.by
- Update to 1.4.4:
  * Remove XML comment here
  * Fix the highlight styling and minor annoyances with the
    preview mode
  * Serve highlight.js from local directory
  * Add highlight.js for code block syntax highlighting
  * Update README.md
* Tue Dec 26 2017 jengelh@inai.de
- Remove filler wording from description.
* Tue Nov 21 2017 avvissu@yandex.by
- Update to 1.4.3:
  * restore COPYING file
  * amp up the text in Light Mode's toolbar
  * enable extra goodies in the Preview mode (initial commit)
  * reduce custom styling // add travis badge on main readme
  * small changes
* Tue Nov  7 2017 avvissu@yandex.by
- Initial package
